Zict
====

|Build Status| |Linting|

Mutable Mapping tools.  See documentation_.

.. _documentation: http://zict.readthedocs.io/en/latest/
.. |Build Status| image:: https://github.com/dask/zict/actions/workflows/test.yml/badge.svg
   :target: https://github.com/dask/zict/actions/workflows/test.yml
.. |Linting| image:: https://github.com/dask/zict/actions/workflows/pre-commit.yml/badge.svg
   :target: https://github.com/dask/zict/actions/workflows/pre-commit.yml
